%% Copyright (c) Cosmo Luca - luca.cosmo@unive.it
%  SHREC2016 - Partial Matching Of Deformable Shapes
%  http://www.dais.unive.it/~shrec2016/


function [geodesicerror_curve, erroroverpart_curve] = compute_performance_indices(Ms, Ns, errors)
%% Computes performance indices given the matchinng errors
% Input:
% - Ms: a cell array of k shapes in canonical pose
% - Ns: a cell array of k matched deformed partial shapes
% - errors: a cell array of matching error vectors as computed by 
%           errors{i} = 'calc_err_baryc(...,Ns{i})'.
% Output:
% - geodesicerror_curve: a set of points of the function f(x) = 'percentage
%                        of points with error lower or equal to x'.
% - erroroverpart_curve: a set of points of the function f(x) = 'mean error
%                        of the shapes with partiality < x'. The partiality
%                        of a shape is computed as:
%                        100*(1-partial_shape_area/canonical_shape_area).
%%%

    thresh = 0:0.005:0.25;

    geodesicerror_curve(2,:) = calc_err_curve(cell2mat(errors), thresh);
    geodesicerror_curve(1,:) = thresh;
     
    
    %Compute mesh partiality (100 - % of missing area)
    partiality = zeros(numel(Ms),1);
    for i=1:numel(Ms)
        Atotal = sum(calc_tri_areas(Ms{i}));
        Apartial = sum(calc_tri_areas(Ns{i}));
        partiality(i) = 100-100*Apartial/Atotal;
    end
    
    part_tresh = [80:-10:20];
    erroroverpart_curve(1,:) = part_tresh;
    for i=1:size(part_tresh,2);
        erroroverpart_curve(2,i) = mean(cell2mat(errors(partiality<=part_tresh(i))));        
    end
    
    
end