%% Copyright (c) Cosmo Luca - luca.cosmo@unive.it
%  SHREC2016 - Partial Matching Of Deformable Shapes
%  http://www.dais.unive.it/~shrec2016/

%% This script contains an example of the evaluation procedure.

addpath(genpath('.'));
close all
clear all

null_models_folder = '.\data\null\';
part_models_folder = '.\data\holes\';
gt_folder =         '.\data\holes\gt\';
matches_folder =    '.\data\holes\sparse_matches\';

files = dir([part_models_folder,'*.off']);

%compute match errors
Ms = cell(numel(files),1);
Ns = cell(numel(files),1);
errors = cell(numel(files),1);
for fi = 1:numel(files)
    fprintf('-------------------------------------\nProcessing shape %d of %d\n',fi, numel(files));
    clear M;
    clear N;
    
    fname = [files(fi).name];
    [~, name, ~] = fileparts(fname);

    null_model = regexp(name,'[^_0-9]*','match');
    null_model = [null_model{2} ''];
    
    M = load_off([null_models_folder, null_model ,'.off']);    
    N = load_off([part_models_folder, name,'.off']);
    
    Ms{fi} = M;
    Ns{fi} = N;
    
    matches_gt = load([gt_folder, name,'.baryc_gt']);
    matches_gt_sym = load([gt_folder, name,'.baryc_gt_sym']);
    matches_in = load([matches_folder, name,'.corr']);
        
    valid_matches = matches_in(:,1)~=-1;
    assert(all(all(matches_in(valid_matches,:)>=0)),'All weights must be positive');
    assert(all(abs(1-sum(matches_in(valid_matches,2:4),2))<1e-4), 'Weights must sum to 1');
    
    fprintf('Calculating normalized geodesic error...\n');

    error_1 = calc_err_baryc(matches_in, matches_gt, M);
    error_2 = calc_err_baryc(matches_in, matches_gt_sym, M);
    if(sum(error_1)<sum(error_2))
        errors{fi} = error_1;
        fprintf('Mean error %.3f\n',mean(error_1));
    else
        errors{fi} = error_2;
        fprintf('Mean error (sym) %.3f\n',mean(error_2));
    end
    
end

%% Compute performance indices
[geodesicerror_curve, erroroverpart_curve] = compute_performance_indices(Ms, Ns, errors);

figure
plot(geodesicerror_curve(1,:), geodesicerror_curve(2,:), 'LineWidth', 2)
set(gca, 'xlim', [0 max(geodesicerror_curve(1,:))])
set(gca, 'ylim', [0 100])
set(gca, 'xgrid', 'on')
set(gca, 'ygrid', 'on')
xlabel('Geodesic error')
ylabel('% Correspondences')

figure
plot(erroroverpart_curve(1,:), erroroverpart_curve(2,:), 'LineWidth', 2)
set(gca, 'xgrid', 'on')
set(gca, 'ygrid', 'on')
ylabel('Mean geodesic error')
xlabel('Partiality')